@@ -124,10 +124,10 @@ def transform_grid_for_grain_type(grid):
 
 def create_grid(spl,
                  var_to_plot,
-                 xmin,
-                 xmax,
-                 ymin,
-                 ymax):
+                 xmin=None,
+                 xmax=None,
+                 ymin=None,
+                 ymax=None):
 
     """Takes the list of dataframes and makes a 2D numpy array of a given variable and some info.
 
@@ -329,7 +329,8 @@ def read_pro(path,var_to_plot= None):
     if var_to_plot:
         var_codes = ['0500','0501',pro_code_dict(var_to_plot,inverse=True)]
     else:
-        var_codes = [pro_code_dict(return_all=True).keys()]
+        var_codes = ['0500', '0501', '0502', '0503', '0506', '0512', '0513', '0515',
+                     '0516', '0535', '0540', '0541']
 
     # Set up the dictionary to be returned. Dictionary is organised by variable name.
 
